==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkScalarBarWidget.java <==
// java wrapper for vtkScalarBarWidget object
//

package vtk;
import vtk.*;

public class vtkScalarBarWidget extends vtkBorderWidget
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetRepresentation_2(vtkScalarBarRepresentation id0);
  public void SetRepresentation(vtkScalarBarRepresentation id0)
    { SetRepresentation_2(id0); }

  private native long GetScalarBarRepresentation_3();
  public vtkScalarBarRepresentation GetScalarBarRepresentation() {
    long temp = GetScalarBarRepresentation_3();

    if (temp == 0) return null;
    return (vtkScalarBarRepresentation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetScalarBarActor_4(vtkScalarBarActor id0);
  public void SetScalarBarActor(vtkScalarBarActor id0)
    { SetScalarBarActor_4(id0); }

  private native long GetScalarBarActor_5();
  public vtkScalarBarActor GetScalarBarActor() {
    long temp = GetScalarBarActor_5();

    if (temp == 0) return null;
    return (vtkScalarBarActor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetRepositionable_6(int id0);
  public void SetRepositionable(int id0)
    { SetRepositionable_6(id0); }

  private native int GetRepositionable_7();
  public int GetRepositionable()
    { return GetRepositionable_7(); }

  private native void RepositionableOn_8();
  public void RepositionableOn()
    { RepositionableOn_8(); }

  private native void RepositionableOff_9();
  public void RepositionableOff()
    { RepositionableOff_9(); }

  private native void CreateDefaultRepresentation_10();
  public void CreateDefaultRepresentation()
    { CreateDefaultRepresentation_10(); }

  public vtkScalarBarWidget() { super(); }

  public vtkScalarBarWidget(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-6-armv7h.pkg.tar.xz: vtk/vtkScalarBarWidget.java <==
// java wrapper for vtkScalarBarWidget object
//

package vtk;
import vtk.*;

public class vtkScalarBarWidget extends vtkBorderWidget
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetRepresentation_2(vtkScalarBarRepresentation id0);
  public void SetRepresentation(vtkScalarBarRepresentation id0)
    { SetRepresentation_2(id0); }

  private native long GetScalarBarRepresentation_3();
  public vtkScalarBarRepresentation GetScalarBarRepresentation() {
    long temp = GetScalarBarRepresentation_3();

    if (temp == 0) return null;
    return (vtkScalarBarRepresentation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetScalarBarActor_4(vtkScalarBarActor id0);
  public void SetScalarBarActor(vtkScalarBarActor id0)
    { SetScalarBarActor_4(id0); }

  private native long GetScalarBarActor_5();
  public vtkScalarBarActor GetScalarBarActor() {
    long temp = GetScalarBarActor_5();

    if (temp == 0) return null;
    return (vtkScalarBarActor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetRepositionable_6(int id0);
  public void SetRepositionable(int id0)
    { SetRepositionable_6(id0); }

  private native int GetRepositionable_7();
  public int GetRepositionable()
    { return GetRepositionable_7(); }

  private native void RepositionableOn_8();
  public void RepositionableOn()
    { RepositionableOn_8(); }

  private native void RepositionableOff_9();
  public void RepositionableOff()
    { RepositionableOff_9(); }

  private native void CreateDefaultRepresentation_10();
  public void CreateDefaultRepresentation()
    { CreateDefaultRepresentation_10(); }

  public vtkScalarBarWidget() { super(); }

  public vtkScalarBarWidget(long id) { super(id); }
  public native long   VTKInit();

}
